==> kleopatra_17.12.3.orig.tar.xz: kleopatra-17.12.3/src/crypto/gui/decryptverifyfileswizard.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    crypto/gui/decryptverifyfileswizard.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2007 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_CRYPTO_GUI_DECRYPTVERIFYFILESWIZARD_H__
#define __KLEOPATRA_CRYPTO_GUI_DECRYPTVERIFYFILESWIZARD_H__

#include <crypto/gui/wizard.h>

#include <utils/pimpl_ptr.h>

#include <memory>

namespace Kleo
{
namespace Crypto
{
class Task;
class TaskCollection;
namespace Gui
{

class DecryptVerifyOperationWidget;

class DecryptVerifyFilesWizard : public Wizard
{
    Q_OBJECT
public:
    enum Page {
        OperationsPage = 0,
        ResultPage
    };

    explicit DecryptVerifyFilesWizard(QWidget *parent = nullptr, Qt::WindowFlags f = 0);
    ~DecryptVerifyFilesWizard();

    void setOutputDirectory(const QString &dir);
    QString outputDirectory() const;
    bool useOutputDirectory() const;

    void setTaskCollection(const std::shared_ptr<TaskCollection> &coll);

    DecryptVerifyOperationWidget *operationWidget(unsigned int idx);

Q_SIGNALS:
    void operationPrepared();

private:
    void onNext(int id) override;

private:
    class Private;
    kdtools::pimpl_ptr<Private> d;
};

}
}
}

#endif /* __KLEOPATRA_CRYPTO_GUI_DECRYPTVERIFYFILESWIZARD_H__ */

==> kleopatra_20.08.3.orig.tar.xz: kleopatra-20.08.3/src/crypto/gui/decryptverifyfileswizard.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    crypto/gui/decryptverifyfileswizard.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2007 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_CRYPTO_GUI_DECRYPTVERIFYFILESWIZARD_H__
#define __KLEOPATRA_CRYPTO_GUI_DECRYPTVERIFYFILESWIZARD_H__

#include <crypto/gui/wizard.h>

#include <utils/pimpl_ptr.h>

#include <memory>

namespace Kleo
{
namespace Crypto
{
class Task;
class TaskCollection;
namespace Gui
{

class DecryptVerifyOperationWidget;

class DecryptVerifyFilesWizard : public Wizard
{
    Q_OBJECT
public:
    enum Page {
        OperationsPage = 0,
        ResultPage
    };

    explicit DecryptVerifyFilesWizard(QWidget *parent = nullptr, Qt::WindowFlags f = {});
    ~DecryptVerifyFilesWizard() override;

    void setOutputDirectory(const QString &dir);
    QString outputDirectory() const;
    bool useOutputDirectory() const;

    void setTaskCollection(const std::shared_ptr<TaskCollection> &coll);

    DecryptVerifyOperationWidget *operationWidget(unsigned int idx);

Q_SIGNALS:
    void operationPrepared();

private:
    void onNext(int id) override;

private:
    class Private;
    kdtools::pimpl_ptr<Private> d;
};

}
}
}

#endif /* __KLEOPATRA_CRYPTO_GUI_DECRYPTVERIFYFILESWIZARD_H__ */
